.. _rscd_step:

===========================================
Reset Switch Charge Decay (RSCD) Correction
===========================================

.. toctree::
   :maxdepth: 2

   description.rst
   arguments.rst
   reference_files.rst

.. automodapi:: jwst.rscd
